@@ -40,13 +40,14 @@ class DISCOVERCOMMON_EXPORT UpdateModel : public QAbstractListModel
 public:
 
     enum Roles {
-        VersionRole = Qt::UserRole + 1,
-        SizeRole,
+        SizeRole = Qt::UserRole + 1,
         ResourceRole,
         ResourceProgressRole,
         SectionResourceProgressRole,
         ChangelogRole,
-        SectionRole
+        SectionRole,
+        InstalledVersionRole,
+        AvailableVersionRole
     };
     Q_ENUM(Roles)
 
@@ -72,13 +73,16 @@ public:
     ///packages marked to upgrade
     int toUpdateCount() const;
 
-    Q_SCRIPTABLE void fetchChangelog(int row);
+    Q_SCRIPTABLE void fetchUpdateDetails(int row);
 
     QString updateSize() const;
 
     ResourcesUpdatesModel* backend() const;
 
 public Q_SLOTS:
+    void checkAll();
+    void uncheckAll();
+
     void setBackend(ResourcesUpdatesModel* updates);
 
 Q_SIGNALS:
