@@ -205,7 +205,6 @@ void OdrsReviewsBackend::reviewsFetched()
     QFile file(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/reviews/%1.json").arg(jsonObject.value(QStringLiteral("app_id")).toString()));
     if (file.open(QIODevice::WriteOnly)) {
         file.write(document.toJson());
-        file.close();
     }
 }
 
@@ -303,7 +302,8 @@ void OdrsReviewsBackend::parseRatings()
     QFile ratingsDocument(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/ratings/ratings"));
     if (ratingsDocument.open(QIODevice::ReadOnly)) {
         QJsonDocument jsonDocument = QJsonDocument::fromJson(ratingsDocument.readAll());
-        QJsonObject jsonObject = jsonDocument.object();
+        const QJsonObject jsonObject = jsonDocument.object();
+        m_ratings.reserve(jsonObject.size());
         for (auto it = jsonObject.begin(); it != jsonObject.end(); it++) {
             QJsonObject appJsonObject = it.value().toObject();
 
@@ -316,6 +316,7 @@ void OdrsReviewsBackend::parseRatings()
                                       { QStringLiteral("star5"), appJsonObject.value(QLatin1String("star5")).toInt() } };
 
             Rating *rating = new Rating(it.key(), ratingCount, ratingMap);
+            rating->setParent(this);
             m_ratings.insert(it.key(), rating);
         }
         ratingsDocument.close();
@@ -336,7 +337,7 @@ void OdrsReviewsBackend::parseReviews(const QJsonDocument &document, AbstractRes
     if (!reviews.isEmpty()) {
         QVector<ReviewPtr> reviewList;
         for (auto it = reviews.begin(); it != reviews.end(); it++) {
-            QJsonObject review = it->toObject();
+            const QJsonObject review = it->toObject();
             if (!review.isEmpty()) {
                 const int usefulFavorable = review.value(QStringLiteral("karma_up")).toInt();
                 const int usefulTotal = review.value(QStringLiteral("karma_down")).toInt() + usefulFavorable;
