@@ -58,11 +58,14 @@ public:
     Transaction* installApplication(AbstractResource* app, const AddonList& addons) override;
     Transaction* removeApplication(AbstractResource* app) override;
     bool isFetching() const override { return m_isFetching>0; }
-    AbstractResource * resourceForFile(const QUrl & ) override;
     void checkForUpdates() override;
     QString displayName() const override;
     bool hasApplications() const override { return true; }
     FlatpakResource * addSourceFromFlatpakRepo(const QUrl &url);
+    QStringList extends() const override { return m_extends; }
+
+    FlatpakResource * addAppFromFlatpakBundle(const QUrl &url);
+    FlatpakResource * addAppFromFlatpakRef(const QUrl &url);
 
 private Q_SLOTS:
     void onFetchMetadataFinished(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource, const QByteArray &metadata);
@@ -73,7 +76,7 @@ Q_SIGNALS: //for tests
     void initialized();
 
 private:
-    bool flatpakResourceLessThan(AbstractResource* l, AbstractResource* r);
+    bool flatpakResourceLessThan(AbstractResource* l, AbstractResource* r) const;
     void announceRatingsReady();
     FlatpakInstallation * preferredInstallation() const { return m_installations.constFirst(); }
     void integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote);
@@ -82,8 +85,6 @@ private:
     FlatpakResource * getAppForInstalledRef(FlatpakInstallation *flatpakInstallation, FlatpakInstalledRef *ref) const;
     FlatpakResource * getRuntimeForApp(FlatpakResource *resource) const;
 
-    FlatpakResource * addAppFromFlatpakBundle(const QUrl &url);
-    FlatpakResource * addAppFromFlatpakRef(const QUrl &url);
     void addResource(FlatpakResource *resource);
     void loadAppsFromAppstreamData();
     bool loadAppsFromAppstreamData(FlatpakInstallation *flatpakInstallation);
@@ -102,6 +103,7 @@ private:
     bool updateAppSizeFromRemote(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource);
     void updateAppState(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource);
 
+    QVector<AbstractResource*> resourcesByAppstreamName(const QString &name) const;
     void acquireFetching(bool f);
 
     QHash<FlatpakResource::Id, FlatpakResource*> m_resources;
@@ -110,6 +112,7 @@ private:
     QSharedPointer<OdrsReviewsBackend> m_reviews;
     uint m_isFetching = 0;
     uint m_refreshAppstreamMetadataJobs;
+    QStringList m_extends;
 
     GCancellable *m_cancellable;
     QVector<FlatpakInstallation *> m_installations;
